@@ -12,8 +12,12 @@ class Response(BaseModel):
     data: Any
     # data: Optional[BaseModel] = None
 
+class ObjectType(str, Enum):
+    ASSETS = "assets"
+    COLLECTIONS = "collections"
 
 class Status(str, Enum):
+    IN_PROGRESS = "IN_PROGRESS"
     ACTIVE = "ACTIVE"
     HIDDEN = "HIDDEN"
     DELETED = "DELETED"
